from interactions import Client, Status
from gwendolyn.utils import log
from dotenv import load_dotenv
from os import getenv

from pymongo import MongoClient  # Used for database management

class Gwendolyn(Client):
    def __init__(self, testing: bool = True):
        """Initialize the bot."""
        initiation_parameters = {
            "status": Status.DND,
            "delete_unused_application_cmds": True
        }
        super().__init__(**initiation_parameters)

        self.testing = testing

        self._add_clients_and_options()
        # self._add_util_classes()
        # self._add_function_containers()
        # self._add_cogs()

    def _add_clients_and_options(self):
        """Add all the client, option and credentials objects."""
        load_dotenv()
        self.bot_token = getenv("DISCORD_TOKEN")

        mongo_user = getenv("MONGODB_USER")
        mongo_password = getenv("MONGODB_PASSWORD")
        mongo_url = f"mongodb+srv://{mongo_user}:{mongo_password}@gwendolyn"
        mongo_url += ".qkwfy.mongodb.net/Gwendolyn?retryWrites=true&w=majority"
        database_client = MongoClient(mongo_url)

        if self.testing:
            self.log("Testing mode")
            self.database = database_client["Gwendolyn-Test"]
        else:
            self.database = database_client["Gwendolyn"]

    def log(self, messages, channel: str = "", level: int = 20): # pylint:disable=no-self-use
        """Log a message. Described in utils/util_functions.py."""
        log(messages, channel, level)

    def start(self):
        super().start(self.bot_token)